BVector

Struct BVector 

pub struct BVector<T: SimdRealField + Copy, const N: usize> {
    pub data_vector: SVector<T, N>,
}
This module provides a vector type BVector that is optimized for compile-time dimension and uses SIMD operations for performance.

Fields

data_vector: SVector<T, N>

Implementations

Source

impl<T: SimdRealField + Copy, const N: usize> BVector<T, N>

pub fn from_element(element: T) -> Self

Constructs a vector filled with element of a dimension N.

pub fn from_array(data: [T; N]) -> Self
where T: Copy,

Constructs the vector from fixed-size array.

pub fn dot(&self, other: &Self) -> T

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

Whether the vector has no elements, which is only the case when N is 0.

pub fn get(&self, index: usize) -> T