pub struct Perceptron<const N: usize> { /* private fields */ }Expand description
Perceptron
This is a single perceptron implementation. It contains weights, bias and an activation function. You can use this struct and its methods to create, manipulate and even implement your ways to train a perceptron (find the weights).
Example
use only_brain::Perceptron;
use only_brain::ActivationFunction;
use only_brain::bvector;
fn main() {
let mut perceptron = Perceptron::<2>::new(ActivationFunction::Sigmoid);
perceptron.set_weights(bvector![0.5, -0.2]);
perceptron.set_bias(0.3);
println!("{}", perceptron);
let inputs = bvector![0.6, 0.4];
let output = perceptron.feed_forward(&inputs);
println!("Output: {}", output);
}Implementations
Sourceimpl<const N: usize> Perceptron<N>
impl<const N: usize> Perceptron<N>
pub fn new(activation_function: ActivationFunction) -> Self
pub fn set_weights(&mut self, weights: BVector<f64, N>)
pub fn set_bias(&mut self, bias: f64)
pub fn feed_forward(&self, inputs: &BVector<f64, N>) -> f64